# frozen_string_literal: true

require "net/http"
require "uri"
require "json"

module WipApi
  class Client
    API_URL = 'https://wip.chat/graphql'

    class << self
      attr_writer :api_key
    end


    def make_request(query)
      http = Net::HTTP.new(api_uri.host, api_uri.port)
      http.use_ssl = true
      header = {
        "Authorization" => "bearer #{api_key}",
        "Content-Type" => "application/json"
      }
      request = Net::HTTP::Post.new(api_uri.request_uri, header)
      request.body = { query: query }.to_json

      # Send the request
      response = http.request(request)

      raise ChangeRejectedError.new(response.message) if response.class.eql?(Net::HTTPUnprocessableEntity)


      json = JSON.parse(response.body)
      if json.has_key? "errors"
        raise json["errors"].first["message"]
      end
      json
    end

    private

    attr_reader :api_key

    def api_uri
      @uri ||= URI.parse(API_URL)
    end
  end
end
